==> zego_uikit-0.0.1.tar.gz: lib/src/components/message/in_room_message_view.dart <==
// Flutter imports:
import 'package:flutter/material.dart';

// Project imports:
import 'package:zego_uikit/src/service/service.dart';
import 'in_room_message_view_item.dart';

class ZegoInRoomMessageView extends StatefulWidget {
  const ZegoInRoomMessageView({
    Key? key,
  }) : super(key: key);

  @override
  State<ZegoInRoomMessageView> createState() => _ZegoInRoomMessageViewState();
}

class _ZegoInRoomMessageViewState extends State<ZegoInRoomMessageView> {
  final ScrollController _scrollController = ScrollController();

  @override
  Widget build(BuildContext context) {
    return StreamBuilder<Object>(
        stream: ZegoUIKit().getInRoomMessagesStream(),
        builder: (context, snapshot) {
          if (snapshot.hasData) {
            var messageList = snapshot.data as List<ZegoInRoomMessage>;
            WidgetsBinding.instance?.addPostFrameCallback((_) {
              _scrollController.animateTo(
                _scrollController.position.maxScrollExtent,
                duration: const Duration(milliseconds: 300),
                curve: Curves.easeOut,
              );
            });
            return ListView.builder(
              shrinkWrap: true,
              controller: _scrollController,
              itemCount: messageList.length,
              itemBuilder: (context, index) {
                return ZegoInRoomMessageViewItem(
                  // todo  how to show host?
                  prefix: messageList[index].sender.id ==
                          ZegoUIKit().getLocalUser().id
                      ? 'Me'
                      : null,
                  user: messageList[index].sender,
                  message: messageList[index].message,
                );
              },
            );
          }
          return const SizedBox();
        });
  }
}

==> zego_uikit-1.1.2.tar.gz: lib/src/components/message/in_room_message_view.dart <==
// Flutter imports:
import 'package:flutter/material.dart';

// Project imports:
import 'package:zego_uikit/src/services/services.dart';
import 'in_room_message_view_item.dart';

class ZegoInRoomMessageView extends StatefulWidget {
  const ZegoInRoomMessageView({
    Key? key,
  }) : super(key: key);

  @override
  State<ZegoInRoomMessageView> createState() => _ZegoInRoomMessageViewState();
}

class _ZegoInRoomMessageViewState extends State<ZegoInRoomMessageView> {
  final ScrollController _scrollController = ScrollController();

  @override
  Widget build(BuildContext context) {
    return StreamBuilder<Object>(
        stream: ZegoUIKit().getInRoomMessagesStream(),
        builder: (context, snapshot) {
          if (snapshot.hasData) {
            var messageList = snapshot.data as List<ZegoInRoomMessage>;
            WidgetsBinding.instance?.addPostFrameCallback((_) {
              _scrollController.animateTo(
                _scrollController.position.maxScrollExtent,
                duration: const Duration(milliseconds: 300),
                curve: Curves.easeOut,
              );
            });
            return ListView.builder(
              shrinkWrap: true,
              controller: _scrollController,
              itemCount: messageList.length,
              itemBuilder: (context, index) {
                return ZegoInRoomMessageViewItem(
                  // todo  how to show host?
                  // prefix: messageList[index].sender.id ==
                  //         ZegoUIKit().getLocalUser().id
                  //     ? 'Me'
                  //     : null,
                  user: messageList[index].sender,
                  message: messageList[index].message,
                );
              },
            );
          }
          return const SizedBox();
        });
  }
}
